@@ -38,3 +38,8 @@ def url_to_array(url):
     else:
         print("http get:{}".format(result.status_code))
         return None
+
+def file_to_array(path):
+    f = Image.open(path)
+    data = imagetool.img_to_array(f)
+    return data
\ No newline at end of file
